@@ -27,7 +27,13 @@ def convert_elementwise_div(node, params, layers, lambda_func, node_name, keras_
 
     try:
         logger.debug('Divide numpy arrays.')
-        layers[node_name] = layers[node.input[0]] / layers[node.input[1]]
+        div = input_0 / input_1
+        if input_0.dtype == input_1.dtype:
+            div = tf.cast(div, input_0.dtype)
+        if hasattr(div, 'numpy'):
+            div = div.numpy()
+        layers[node_name] = div
+
     except (IndexError, ValueError):
         logger.debug('Convert inputs to Keras/TF layers if needed.')
 
@@ -80,6 +86,7 @@ def convert_elementwise_add(node, params, layers, lambda_func, node_name, keras_
         else:
             layers[node_name] = input_0 + input_1
 
+
 def convert_elementwise_mul(node, params, layers, lambda_func, node_name, keras_name):
     """
     Convert element-wise mul.
@@ -218,7 +225,8 @@ def convert_equal(node, params, layers, lambda_func, node_name, keras_name):
 
 
 def convert_where(node, params, layers, lambda_func, node_name, keras_name):
-    layers[node_name] = np.where(layers[node.input[0]], layers[node.input[1]],  layers[node.input[2]])
+    layers[node_name] = np.where(layers[node.input[0]], layers[node.input[1]], layers[node.input[2]])
+
 
 def convert_scatter_nd(node, params, layers, lambda_func, node_name, keras_name):
     """
